@@ -25,17 +25,10 @@
  */
 
 
-#include <GormCore/GormGenericEditor.h>
-#include <GormCore/GormPrivate.h>
-#include <GormCore/GormFontViewController.h>
-#include <GormCore/GormSetNameController.h>
-#include <GormCore/GormFunctions.h>
-#include <GormCore/GormPluginManager.h>
-#include <GormCore/GormDocumentController.h>
-#include <GormCore/GormServer.h>
+#include <GormCore/GormCore.h>
+#include <GormPrefs/GormPrefs.h>
 
 #include <GNUstepBase/GSObjCRuntime.h>
-#include <GormPrefs/GormPrefController.h>
 
 @interface Gorm : NSApplication <IB, Gorm>
 {
@@ -81,6 +74,23 @@
   return [[NSDocumentController sharedDocumentController] currentDocument];
 }
 
+/*
+   NSApplication override to make Inspector's shortcuts available globally
+*/
+- (void) sendEvent: (NSEvent *)theEvent
+{
+  if ([theEvent type] == NSKeyDown)
+    {
+      NSPanel *inspector = [[self inspectorsManager] panel];
+      if ([inspector performKeyEquivalent: theEvent] != NO)
+        {
+          [inspector orderFront: self];
+          return;
+        }
+    }
+  [super sendEvent: theEvent];
+}
+
 /*
    NSApp
 */
@@ -764,12 +774,12 @@
  					object:nil];
   if ( [guideLineMenuItem tag] == 0 )
     {
-      [guideLineMenuItem setTitle:_(@"Enable GuideLine")];
+      [guideLineMenuItem setTitle:_(@"Turn GuideLine On")];
       [guideLineMenuItem setTag:1];
     }
   else if ( [guideLineMenuItem tag] == 1)
     {
-      [guideLineMenuItem setTitle:_(@"Disable GuideLine")];
+      [guideLineMenuItem setTitle:_(@"Turn GuideLine Off")];
       [guideLineMenuItem setTag:0];
     }
 }
