@@ -22,9 +22,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <InterfaceBuilder/IBObjectAdditions.h>
+#include <Foundation/Foundation.h>
 #include <AppKit/AppKit.h>
-#include <Foundation/NSArchiver.h>
+
+#include <InterfaceBuilder/InterfaceBuilder.h>
 
 #include "GormPrivate.h"
 #include "GormViewWithSubviewsEditor.h"
