@@ -22,13 +22,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include "GormViewWindow.h"
-#include <AppKit/NSWindow.h>
-#include <AppKit/NSView.h>
-#include <AppKit/NSColor.h>
-#include <Foundation/NSNotification.h>
-#include <Foundation/NSException.h>
+#include <Foundation/Foundation.h>
+#include <AppKit/AppKit.h>
+
 #include <InterfaceBuilder/InterfaceBuilder.h>
+
+#include "GormViewWindow.h"
 #include "GormFunctions.h"
 
 @interface GormViewWindowDelegate : NSObject
