@@ -8,16 +8,16 @@
  * This file is part of GNUstep.
  * 
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
@@ -25,7 +25,8 @@
 #ifndef INCLUDED_IBDOCUMENTS_H
 #define INCLUDED_IBDOCUMENTS_H
 
-#include <Foundation/NSGeometry.h>
+#include <Foundation/Foundation.h>
+
 #include <InterfaceBuilder/IBEditors.h>
 #include <InterfaceBuilder/IBConnectors.h>
 #include <InterfaceBuilder/IBSystem.h>
@@ -211,6 +212,16 @@ IB_EXTERN NSString *IBWillCloseDocumentNotification;
  * Mark document as having been changed.	
  */
 - (void) touch;		
+
+////  PRIVATE
+/**
+ * Returns a string with the name of the class for the given object.
+ */
+
+- (NSString *) classForObject: (id)obj;
+- (NSArray *) actionsOfClass: (NSString *)className;
+- (NSArray *) outletsOfClass: (NSString *)className;
+
 @end
 
 #endif
