@@ -34,7 +34,7 @@
 #ifndef INCLUDED_GormMatrixAttributesInspector_h
 #define INCLUDED_GormMatrixAttributesInspector_h
 
-#include <InterfaceBuilder/IBInspector.h>
+#include <InterfaceBuilder/InterfaceBuilder.h>
 
 @class NSButton;
 @class NSColorWell;
@@ -53,7 +53,8 @@
   NSMatrix *prototypeMatrix;
   NSButton *selRectSwitch;
   NSForm *tagForm;
-  NSForm *dimensionsForm;
+  NSForm *rowsForm;
+  NSForm *colsForm;
   NSStepper *rowsStepper;
   NSStepper *colsStepper;
 }
