@@ -31,19 +31,13 @@
   Author : Fabien Vallon <fabien@sonappart.net>
 */
 
+#include <Foundation/Foundation.h>
+#include <AppKit/AppKit.h>
+
+#include <GormCore/GormCore.h>
 
 #include "GormTextFieldAttributesInspector.h"
 
-#include <GormCore/NSColorWell+GormExtensions.h>
-
-#include <Foundation/NSNotification.h>
-
-#include <AppKit/NSButton.h>
-#include <AppKit/NSForm.h>
-#include <AppKit/NSMatrix.h>
-#include <AppKit/NSNibLoading.h>
-#include <AppKit/NSTextField.h>
-
 
 /*
   IBObjectAdditions category
@@ -136,6 +130,10 @@
       BOOL sendActionOnEndEditing = ([[sender cellAtRow: 1 column: 0] state] == NSOnState);
       [[object cell] setSendsActionOnEndEditing: sendActionOnEndEditing];
     }
+  else if (sender == singleLineMode)
+    {
+      [[object cell] setUsesSingleLineMode: [singleLineMode state]];
+    }
 
   [super ok:sender];
 }
@@ -155,7 +153,8 @@
   [editableSwitch setState:[object isEditable]];
   [selectableSwitch setState:[object isSelectable]];
   [scrollableSwitch setState:[[object cell] isScrollable]];
-
+  [singleLineMode setState:[[object cell] usesSingleLineMode]];
+  
   if ([object isBordered] == YES)
     {
       [borderMatrix selectCellAtRow: 0 column: 1];
